@@ -252,8 +252,6 @@ static void mtp008_sens(struct i2c_client *client, int operation,
 			int ctl_name, int *nrels_mag, long *results);
 static void mtp008_getsensortype(struct mtp008_data *data, u8 inp);
 
-static int mtp008_id = 0;
-
 static struct i2c_driver mtp008_driver =
 {
 	.name		= "MTP008 sensor driver",
@@ -274,9 +272,9 @@ static struct i2c_driver mtp008_driver =
 #define MTP008_SYSCTL_FAN1	1101	/* Rotations/min */
 #define MTP008_SYSCTL_FAN2	1102
 #define MTP008_SYSCTL_FAN3	1103
-#define MTP008_SYSCTL_TEMP1	1200	/* Degrees Celcius * 10 */
-#define MTP008_SYSCTL_TEMP2	1201	/* Degrees Celcius * 10 */
-#define MTP008_SYSCTL_TEMP3	1202	/* Degrees Celcius * 10 */
+#define MTP008_SYSCTL_TEMP1	1200	/* Degrees Celsius * 10 */
+#define MTP008_SYSCTL_TEMP2	1201	/* Degrees Celsius * 10 */
+#define MTP008_SYSCTL_TEMP3	1202	/* Degrees Celsius * 10 */
 #define MTP008_SYSCTL_VID	1300	/* Volts * 100 */
 #define MTP008_SYSCTL_PWM1	1401
 #define MTP008_SYSCTL_PWM2	1402
@@ -428,8 +426,6 @@ int mtp008_detect(struct i2c_adapter *adapter, int address,
 	client_name = "MTP008 chip";
 	strcpy(new_client->name, client_name);
 	data->type = kind;
-
-	new_client->id = mtp008_id++;
 	data->valid = 0;
 	init_MUTEX(&data->update_lock);
 
@@ -497,7 +493,7 @@ static int mtp008_write_value(struct i2c_client *client, u8 reg, u8 value)
 	return i2c_smbus_write_byte_data(client, reg, value);
 }
 
-/* Called when we have found a new MTP008. It should set limits, etc. */
+/* Called when we have found a new MTP008. */
 static void mtp008_init_client(struct i2c_client *client)
 {
 	u8 save1, save2;
